# DarthVader

## To understand how packaging works

I am gonna:

1. create module within folder `core`
2. create shell scripts inside `shell`

## To understand system args

I am gonna:

1. experiment with the scope of args
2. understand how `sys.argv` works
3. check the possiblity of switching to `argparse`
"# darthvader" 
